==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/vyroba/vyrobafilterform.php <==
<?php
/**
 * stanislav.elbl, 04.10.2021 23:34
 */

namespace RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\TextManager;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSettings;

class VyrobaFilterForm extends RonPortalFilterForm
{
    private $datumZpracovaniVyroby;

    private static $typRozdeleni;
    private static $typRozdeleni2;

    /**
     * @param Database $database
     * @param PravaNaOsoby|PravaNaOsoby[] $prava
     * @param bool $den
     * @param int $datumZpracovaniVyroby
     * @param int $typRozdeleni
     * @param int $typRozdeleni2
     */
    public function __construct(Database $database, $prava, $den, $datumZpracovaniVyroby, $typRozdeleni, $typRozdeleni2)
    {
        parent::__construct($database, 'vyroba', true);
        $this->hiddenFields['action'] = 'denni';

        if ($typRozdeleni !== RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP)) {
            $this->nastavRozdeleni(true, $typRozdeleni, 0, '', true);
        } else {
            $this->nastavRozdeleni(true);
        }

        if (!empty($typRozdeleni2)) {
            $this->nastavRozdeleni2(true, $typRozdeleni2, 0, '', true);
        }

        static::$typRozdeleni = $this->f_typrozdeleni;
        static::$typRozdeleni2 = $this->f_typrozdeleni2;

        $this->nastavOsoby(true, $prava, $den, $den);
        $this->povolitVsechyOsoby = true;

        $this->datumZpracovaniVyroby = $datumZpracovaniVyroby;
    }

    public function renderFilterDatum()
    {
        echo "<div class='filterrow'>";

        echo "<span class='filtercaption'>";
        echo TextManager::_('Vyroba_den');
        echo "</span>";

        echo '<span style="white-space:nowrap;">';

        $submitstr = $this->f_autosubmit ? "data-roncalendar-submit='1'" : '';
        $valueStr = date('j.n.Y', static::getDen());
        $maxDatum = date('j.n.Y', $this->datumZpracovaniVyroby);

        echo "<input type='text' class='inputDate' size='10' maxlength='10' name='den' value='$valueStr' $submitstr data-roncalendar-maxdate='$maxDatum'>";
        echo "<i class='showcalendar inline-glyph glyph-button fa glyph-calendar' data-roncalendar-inputname='den'></i>";


        echo "</span>";
        echo "</div>";
    }

    function renderFilters()
    {
        $this->renderFilterDatum();
        parent::renderFilters();
    }

    /**
     * @return int
     */
    public static function getDen()
    {
        try {
            $den = isset($_POST['den'])
                ? DateUtils::dateStringToTimestamp($_POST['den'])
                : (isset($_GET['den']) ? DateUtils::dateStringToTimestamp($_GET['den']) : DateUtils::today());
        } catch (\Exception $exception) {
            $den = DateUtils::today();
        }
        return $den;
    }

    public static function getTypRozdeleni()
    {
        return static::$typRozdeleni;
    }

    public static function getTypRozdeleni2()
    {
        return static::$typRozdeleni2;
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/vyroba/vyrobafilterform.php <==
<?php
/**
 * stanislav.elbl, 04.10.2021 23:34
 */

namespace RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\TextManager;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSettings;

class VyrobaFilterForm extends RonPortalFilterForm
{
    private $datumZpracovaniVyroby;

    // TODO: predelat - zrusit static, pouzit $kodTypuRozdeleni z predka
    private static $typRozdeleni;
    private static $typRozdeleni2;

    /**
     * @param Database $database
     * @param PravaNaOsoby|PravaNaOsoby[] $prava
     * @param bool $den
     * @param int $datumZpracovaniVyroby
     * @param int $typRozdeleni
     * @param int $typRozdeleni2
     */
    public function __construct(Database $database, $prava, $den, $datumZpracovaniVyroby, $typRozdeleni, $typRozdeleni2)
    {
        parent::__construct($database, 'vyroba', true);
        $this->hiddenFields['action'] = 'denni';

        if ($typRozdeleni !== RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI_TYP)) {
            $this->nastavRozdeleni(true, $typRozdeleni, 0, '', true);
        } else {
            $this->nastavRozdeleni(true);
        }

        if (!empty($typRozdeleni2)) {
            $this->nastavRozdeleni2(true, $typRozdeleni2, 0, '', true);
        }

        static::$typRozdeleni = $this->kodTypuRozdeleni;
        static::$typRozdeleni2 = $this->kodTypuRozdeleni2;

        $this->nastavOsoby(true, $prava, $den, $den);
        $this->povolitVsechyOsoby = true;

        $this->datumZpracovaniVyroby = $datumZpracovaniVyroby;
    }

    // TODO: predelat a zrusit - pouzit $zobrazitDnyObdobi z predka
    public function renderFilterDatum()
    {
        echo "<div class='filterrow'>";

        echo "<span class='filtercaption'>";
        echo TextManager::_('Vyroba_den');
        echo "</span>";

        echo '<span style="white-space:nowrap;">';

        $submitstr = $this->f_autosubmit ? "data-roncalendar-submit='1'" : '';
        $valueStr = date('j.n.Y', static::getDen());
        $maxDatum = date('j.n.Y', $this->datumZpracovaniVyroby);

        echo "<input type='text' class='inputDate' size='10' maxlength='10' name='den' value='$valueStr' $submitstr data-roncalendar-maxdate='$maxDatum'>";
        echo "<i class='showcalendar inline-glyph glyph-button fa glyph-calendar' data-roncalendar-inputname='den'></i>";


        echo "</span>";
        echo "</div>";
    }

    function renderFilters()
    {
        $this->renderFilterDatum();
        parent::renderFilters();
    }

    /**
     * @return int
     */
    public static function getDen()
    {
        try {
            $den = isset($_POST['den'])
                ? DateUtils::dateStringToTimestamp($_POST['den'])
                : (isset($_GET['den']) ? DateUtils::dateStringToTimestamp($_GET['den']) : DateUtils::today());
        } catch (\Exception $exception) {
            $den = DateUtils::today();
        }
        return $den;
    }

    public static function getTypRozdeleni()
    {
        return static::$typRozdeleni;
    }

    public static function getTypRozdeleni2()
    {
        return static::$typRozdeleni2;
    }
}
